# Changelog

## [Unreleased]

## [0.1.3] - 2023-12-27

- Fixes capitalization of IPython (#1)

## [0.1.2] - 2023-12-27

- Adjusts grammar in README.md

## [0.1.1] - 2023-12-27

- Fixes README.md
- Improves examples by having less cells

## [0.1.0] - 2023-12-27

_First release._
